@@ -111,15 +111,15 @@ oanda <- function(instrument,
                                            requests, " requests will be made. Continue? [Y/n] "))
       if (continue %in% c("n", "N", "no", "NO")) stop("Request cancelled by user", call. = FALSE)
       message("Request started with rate limiting in place >>>")
-      list <- lapply(1:requests, function(i) {
-        data <- getPrices(instrument = instrument, granularity = granularity,
-                          from = strftime(first[[i]], format = "%Y-%m-%dT%H:%M:%S"),
-                          to = strftime(second[[i]], format = "%Y-%m-%dT%H:%M:%S"),
-                          price = price, server = server, apikey = apikey)
+      list <- vector(mode = "list", length = requests)
+      for (i in seq_len(requests)) {
+        list[[i]] <- getPrices(instrument = instrument, granularity = granularity,
+                               from = strftime(first[[i]], format = "%Y-%m-%dT%H:%M:%S"),
+                               to = strftime(second[[i]], format = "%Y-%m-%dT%H:%M:%S"),
+                               price = price, server = server, apikey = apikey)
         message("Downloaded data partition ", i, " of ", requests)
         if (i != requests) Sys.sleep(1)
-        data
-      })
+      }
       message("Merging data partitions...")
       df <- do.call(df_merge, list)
       message("Complete")
@@ -181,9 +181,9 @@ getPrices <- function(instrument, granularity, count, from, to, price, server,
   headers <- rawToChar(resp$headers)
   hdate <- strsplit(headers, "date: | GMT", perl = TRUE)[[1L]][2L]
   timestamp <- as.POSIXct.POSIXlt(strptime(hdate, format = "%a, %d %b %Y %H:%M:%S", tz = "UTC"))
-  data <- parse_json(rawToChar(resp$content), simplifyVector = TRUE)$candles
+  data <- parse_json(rawToChar(resp$content), simplifyVector = TRUE)[["candles"]]
 
-  time <- strptime(data$time, format = "%Y-%m-%dT%H:%M:%S", tz = "UTC")
+  time <- strptime(.subset2(data, "time"), format = "%Y-%m-%dT%H:%M:%S", tz = "UTC")
   if (!missing(.validate) && .validate == FALSE) {
     time <- as.POSIXct.POSIXlt(time)
   } else {
@@ -212,15 +212,15 @@ getPrices <- function(instrument, granularity, count, from, to, price, server,
     time <- time + periodicity
   }
 
-  ohlc <- switch(price, M = data$mid, B = data$bid, A = data$ask)
+  ohlc <- switch(price, M = .subset2(data, "mid"), B = .subset2(data, "bid"), A = .subset2(data, "ask"))
 
   df <- list(.POSIXct(time),
-             as.numeric(ohlc$o),
-             as.numeric(ohlc$h),
-             as.numeric(ohlc$l),
-             as.numeric(ohlc$c),
-             data$volume,
-             data$complete)
+             as.numeric(.subset2(ohlc, "o")),
+             as.numeric(.subset2(ohlc, "h")),
+             as.numeric(.subset2(ohlc, "l")),
+             as.numeric(.subset2(ohlc, "c")),
+             .subset2(data, "volume"),
+             .subset2(data, "complete"))
   attributes(df) <- list(names = c("time", "open", "high", "low", "close", "volume", "complete"),
                          class = "data.frame",
                          row.names = .set_row_names(length(time)),
@@ -293,9 +293,9 @@ oanda_stream <- function(instrument, server, apikey) {
   message("Streaming data... Press 'Esc' to return")
   on.exit(expr = return(invisible()))
   curl_fetch_stream(url = url, handle = h, fun = function(x) {
-    stream <- sub("close", "\033[49m\033[39m\nclose",
-                  sub("asks:", "\033[49m\033[39m asks: \033[90m\033[42m",
-                      sub("bids:", "\nbids: \033[37m\033[44m",
+    stream <- sub("close", "\u001b[27m\nclose",
+                  sub("asks:", "\u001b[27m asks:\u001b[7m ",
+                      sub("bids:", "\nbids:\u001b[7m ",
                           gsub(",", "  ",
                                gsub('"|{|}|\\[|\\]', "", rawToChar(x), perl = TRUE),
                                fixed = TRUE), fixed = TRUE), fixed = TRUE), fixed = TRUE)
@@ -369,24 +369,24 @@ oanda_chart <- function(instrument,
   theme <- match.arg(theme)
   server <- if (missing(server)) do_oanda$getServer() else match.arg(server, c("practice", "live"))
   if (!is.numeric(refresh) || refresh < 1) {
-    message("Specified refresh interval invalid - falling back to default of 5 secs")
+    message("Specified refresh interval invalid - reverting to default of 5 secs")
     refresh <- 5
   }
   if (is.numeric(periods) && length(periods) == 3L && all(periods >= 1)) {
     periods <- as.integer(periods)
   } else {
-    warning("Specified cloud periods invalid - falling back to defaults c(9L, 26L, 52L)", call. = FALSE)
+    warning("Specified cloud periods invalid - reverting to defaults c(9L, 26L, 52L)", call. = FALSE)
     periods <- c(9L, 26L, 52L)
   }
   p2 <- periods[2L]
   minlen <- p2 + periods[3L]
   if (!is.numeric(count) || count < minlen) {
-    message("Specified 'count' invalid - falling back to default of 250")
+    message("Specified 'count' invalid - reverting to default of 250")
     count <- 250
   }
 
   ins <- do_oanda$getInstruments(server = server, apikey = apikey)
-  ticker <- ins$displayName[ins$name %in% instrument]
+  ticker <- .subset2(ins, "displayName")[.subset2(ins, "name") %in% instrument]
   periodicity <- switch(granularity,
                         M = 2419200, W = 604800, D = 86400, H12 = 43200, H8 = 28800,
                         H6 = 21600, H4 = 14400, H3 = 10800, H2 = 7200, H1 = 3600,
@@ -408,9 +408,9 @@ oanda_chart <- function(instrument,
   on.exit(expr = return(invisible(pdata)))
   while (TRUE) {
     pdata <- ichimoku.data.frame(data, periods = periods, ...)[minlen:(xlen + p2 - 1L), ]
-    subtitle <- paste(instrument, ptype, "price [",
-                      data$close[xlen], "] at", attr(data, "timestamp"),
-                      "| Chart:", ctype, "| Cmplt:", data$complete[xlen])
+    subtitle <- paste(instrument, ptype, "price [", data$close[xlen],
+                      "] at", attr(data, "timestamp"), "| Chart:", ctype,
+                      "| Cmplt:", .subset2(data, "complete")[xlen])
     plot.ichimoku(pdata, ticker = ticker, subtitle = subtitle, theme = theme,
                   newpage = FALSE, ...)
     Sys.sleep(refresh)
@@ -482,7 +482,7 @@ oanda_studio <- function(instrument = "USD_JPY",
 
     if (missing(apikey)) apikey <- do_oanda$getKey()
     if (!is.numeric(refresh) || refresh < 1) {
-      message("Specified refresh interval invalid - falling back to default of 5 secs")
+      message("Specified refresh interval invalid - reverting to default of 5 secs")
       refresh <- 5
     }
     granularity <- match.arg(granularity)
@@ -492,59 +492,55 @@ oanda_studio <- function(instrument = "USD_JPY",
     if (is.numeric(periods) && length(periods) == 3L && all(periods >= 1)) {
       periods <- as.integer(periods)
     } else {
-      warning("Specified cloud periods invalid - falling back to defaults c(9L, 26L, 52L)", call. = FALSE)
+      warning("Specified cloud periods invalid - reverting to defaults c(9L, 26L, 52L)", call. = FALSE)
       periods <- c(9L, 26L, 52L)
     }
     p2 <- periods[2L]
     minlen <- p2 + periods[3L]
     if (!is.numeric(count) || count <= minlen) {
-      message("Specified 'count' invalid - falling back to default of 300")
+      message("Specified 'count' invalid - reverting to default of 300")
       count <- 300
     }
 
     ins <- do_oanda$getInstruments(server = srvr, apikey = apikey)
-    ichimoku_stheme <- if (requireNamespace("bslib", quietly = TRUE)) {
-      bslib::bs_theme(version = 4, bootswatch = "solar", bg = "#ffffff", fg = "#002b36", primary = "#073642", font_scale = 0.85)
-    }
+    dispnamevec <- .subset2(ins, "displayName")
+    namevec <- .subset2(ins, "name")
 
     ui <- shiny::fluidPage(
-      theme = ichimoku_stheme,
+      shiny::tags$head(shiny::tags$style("
+    #chart {height: calc(100vh - 147px) !important}
+    .control-label {font-weight: 400}
+  ")),
       shiny::fillPage(
         padding = 20,
-        shiny::tags$style(type = "text/css", "#chart {height: calc(100vh - 150px) !important;}"),
         shiny::plotOutput("chart", width = "100%",
                           hover = shiny::hoverOpts(id = "plot_hover", delay = 80, delayType = "throttle")),
         shiny::uiOutput("hover_x"), shiny::uiOutput("hover_y"), shiny::uiOutput("infotip")
       ),
       shiny::fluidRow(
-        shiny::column(width = 12,
-                      shiny::HTML("&nbsp;")
+        shiny::column(width = 12, shiny::HTML("&nbsp;")
         )
       ),
       shiny::fluidRow(
         shiny::column(width = 2,
                       shiny::selectInput("theme", label = "Theme",
                                          choices = c("original", "dark", "solarized", "mono"),
-                                         selected = theme,
-                                         selectize = FALSE)),
+                                         selected = theme, selectize = FALSE)),
         shiny::column(width = 2,
                       shiny::selectInput("instrument", label = "Instrument",
                                          choices = ins$name,
-                                         selected = instrument,
-                                         selectize = FALSE)),
+                                         selected = instrument, selectize = FALSE)),
         shiny::column(width = 1,
                       shiny::selectInput("granularity", label = "Granularity",
                                          choices = c("M", "W", "D",
                                                      "H12", "H8", "H6", "H4", "H3", "H2", "H1",
                                                      "M30", "M15", "M10", "M5", "M4", "M2", "M1",
                                                      "S30", "S15", "S10", "S5"),
-                                         selected = granularity,
-                                         selectize = FALSE)),
+                                         selected = granularity, selectize = FALSE)),
         shiny::column(width = 1,
                       shiny::selectInput("price", label = "Price",
                                          choices = c("M", "B", "A"),
-                                         selected = price,
-                                         selectize = FALSE)),
+                                         selected = price, selectize = FALSE)),
         shiny::column(width = 1,
                       shiny::numericInput("refresh", label = "Refresh",
                                           value = refresh, min = 1, max = 86400)),
@@ -553,10 +549,8 @@ oanda_studio <- function(instrument = "USD_JPY",
                       shiny::downloadButton("savedata", label = "> Archive"),
                       shiny::HTML("</div>")),
         shiny::column(width = 3,
-                      shiny::sliderInput("count", label = "Data Periods",
-                                         min = 100, max = 800,
-                                         value = count,
-                                         width = "100%")),
+                      shiny::sliderInput("count", label = "Data Periods", min = 100,
+                                         max = 800, value = count, width = "100%")),
         shiny::column(width = 1,
                       shiny::HTML("<label class='control-label'>Show</label>"),
                       shiny::checkboxInput("infotip", "Infotip", value = TRUE))
@@ -594,7 +588,7 @@ oanda_studio <- function(instrument = "USD_JPY",
                S30 = "30 Secs", S15 = "15 Secs", S10 = "10 Secs", S5 = "5 Secs")
       )
       ptype <- shiny::reactive(switch(input$price, M = "mid", B = "bid", A = "ask"))
-      dispname <- shiny::reactive(ins$displayName[ins$name %in% input$instrument])
+      dispname <- shiny::reactive(dispnamevec[namevec %in% input$instrument])
 
       newdata <- shiny::reactive({
         shiny::req(input$refresh >= 1)
@@ -635,22 +629,17 @@ oanda_studio <- function(instrument = "USD_JPY",
       xlen <- shiny::reactive(dim(data())[1L])
       pdata <- shiny::reactive(ichimoku(data(), ticker = input$instrument,
                                         periods = periods, ...)[minlen:(xlen() + p2 - 1L), ])
+      plen <- shiny::reactive(xlen() + p2 - minlen)
       ticker <- shiny::reactive(paste(dispname(), "  |", input$instrument, ptype(), "price [",
                                       data()$close[xlen()], "] at", attr(data(), "timestamp"),
-                                      "| Chart:", ctype(), "| Cmplt:", data()$complete[xlen()]))
-
-      if (requireNamespace("bslib", quietly = TRUE)) {
-        shiny::observe({
-          session$setCurrentTheme(
-            bslib::bs_theme_update(ichimoku_stheme, bootswatch = switch(input$theme, dark = "solar", NULL)))
-        })
-      }
+                                      "| Chart:", ctype(), "| Cmplt:",
+                                      .subset2(data(), "complete")[xlen()]))
 
       output$chart <- shiny::renderPlot(
         autoplot.ichimoku(pdata(), ticker = ticker(), theme = input$theme, ...)
       )
       output$hover_x <- shiny::renderUI({
-        shiny::req(input$plot_hover, posi_x() > 0, posi_x() <= dim(pdata())[1L])
+        shiny::req(input$plot_hover, posi_x() > 0, posi_x() <= plen())
         drawGuide(label = index(pdata())[posi_x()], left = left_px() - 17, top = 45)
       })
       output$hover_y <- shiny::renderUI({
@@ -658,7 +647,7 @@ oanda_studio <- function(instrument = "USD_JPY",
         drawGuide(label = signif(input$plot_hover$y, digits = 5), left = 75, top = top_px() + 11)
       })
       output$infotip <- shiny::renderUI({
-        shiny::req(input$infotip, input$plot_hover, posi_x() > 0, posi_x() <= dim(pdata())[1L])
+        shiny::req(input$infotip, input$plot_hover, posi_x() > 0, posi_x() <= plen())
         drawInfotip(sdata = pdata()[posi_x(), ], left_px = left_px(), top_px = top_px())
       })
 
